@@ -16,6 +16,17 @@ dateformat="%Y-%m-%d %H:%M:%S" #the date/time is stored in this format in the re
 LogFile="/home/user/MyDocs/SleepAnalyser/SleepAnalyser.log" #Place for log file. IF YOU CHANGE THIS PATH, YOU ALSO HAVE TO CHANGE IT IN /usr/bin/sleepanalyser!
 
 
+
+#DEFAULT VALUES
+Yscale_Movement_default=2  #Y stretching of yellow movement bars
+DelayStartTime_default=10 #Default recording start delay
+Yscale_Sleep_Pattern_default=40 #Y stretching of blue sleep pattern
+Yoffset_Sleep_Pattern_default= 0  #Y offset of blue sleep pattern
+
+
+
+
+
 GraphBitMap=""
 GraphBitMapLen=0
 GraphBitMapHeight=0
@@ -36,14 +47,23 @@ Value_smoothing=10 #value_smoothing at 2. level
 Derivation=5 #shift in Derivation
 
 Ysize=121 #default value Y scale in px
-Yscale=2 #default value Y stretching
+
+
+
+
+
+Yscale_Movement=0 #Y stretching of yellow movement bars
+DelayStartTime=0
+Yscale_Sleep_Pattern=0  #Y stretching of blue sleep pattern
+Yoffset_Sleep_Pattern= 0 #Y offset of blue sleep pattern
+
 arrXscale=[1, 4, 6] #scaling steps X accis
 arrXscaleLen=3
 Xscale=1 #default value X scale in arraXscale index
 
 derivation_offset=2
 
-Yscale_sleep=1
+#Yscale_Movement_sleep=1
 
 Value_index=0
 Values_total=0
@@ -53,7 +73,7 @@ arrRecordFilesIndex=0
 
 Trigger=14 #Trigger level for movement
 maxTrigger=120
-minTrigger = 10
+minTrigger = 1
 
 
 Light_Sleep_Level=70
@@ -80,7 +100,6 @@ user=""
 app_path="./"
 #passed_time=0
 #passed_time2=0
-DelayStartTime=10
 #DropIndexes=0
 last_beep=0
 #graphBlocks=0
@@ -146,12 +165,12 @@ Awake_Color=                "#860000" #red
 Awake_ColorDark=         "#4C0000"
 
 
-Sleep_Pattern_Yoffset= 0  #move blue graph x pixel down (cut bottom off)
+
 
 
 noiseReduction=4  #Smoothing of derivation data
 
-FilterScale=40
+
 limitMovement=250
 
 
