@@ -128,7 +128,7 @@ def ProcessData(ProcessAll=False, ShowFiltered=False):  #DERIVATION (ABLEITUNG)
             Yder=0
             Zder=0
             XYZderivation=0
-#        records.arrData[4][i]=min(XYZderivation*data.Yscale,  data.Ysize-17) #cut off if higher than graph border
+#        records.arrData[4][i]=min(XYZderivation*data.Yscale_Movement,  data.Ysize-17) #cut off if higher than graph border
         records.arrData[4][i]=abs(XYZderivation-data.derivation_offset)
 
 #    for i in range(0, min(records.Index-data.Derivation, 200)): records.arrData[4][i]=20 #debug
@@ -156,9 +156,9 @@ def Generate_Sleep_Pattern():
         arrSend[i]=records.arrData[4][i]
 
     #Exported function:
-#    arrRet=mylib.sleep_filter(arfunctions_record.pyrSend, records.Index-data.Derivation, filter_data.arrFilter, filter_data.FilterShift, (61-data.FilterScale)*100, data.Ysize-7, 13, data.limitMovement)
-#sleep_filter(ar, len, filter,  shift, Yscale, Yoffset, Ymax, Ymin, limitMovement)
-    arrRet=mylib.sleep_filter(arrSend, records.Index-data.Derivation, filter_data.arrFilter, filter_data.FilterShift, data.FilterScale, data.Sleep_Pattern_Yoffset, data.Ysize-7, 13, data.limitMovement)
+#    arrRet=mylib.sleep_filter(arfunctions_record.pyrSend, records.Index-data.Derivation, filter_data.arrFilter, filter_data.FilterShift, (61-data.Yscale_Sleep_Pattern)*100, data.Ysize-7, 13, data.limitMovement)
+#sleep_filter(ar, len, filter,  shift, Yscale_Movement, Yoffset, Ymax, Ymin, limitMovement)
+    arrRet=mylib.sleep_filter(arrSend, records.Index-data.Derivation, filter_data.arrFilter, filter_data.FilterShift, data.Yscale_Sleep_Pattern, data.Yoffset_Sleep_Pattern, data.Ysize-7, 13, data.limitMovement)
 
     for i in range(0,  records.Index-data.Derivation): #copy array and scale
         records.arrData[6][i]  = arrRet[i]
@@ -195,8 +195,8 @@ def DrawGraph(self,  QtGui, ShowFiltered=False):
 #        if(data.run==False):  #only draw background for sleep levels when recording is finished
         paint.setPen(QtGui.QColor(data.GraphBackground2))
         paint.setBrush(QtGui.QColor(data.GraphBackground2))
-        h1=(data.Ysize-(data.Deep_Sleep_Level*data.Yscale/2))
-        h2=(data.Ysize-(data.Light_Sleep_Level*data.Yscale/2))
+        h1=(data.Ysize-(data.Deep_Sleep_Level*data.Yscale_Movement/2))
+        h2=(data.Ysize-(data.Light_Sleep_Level*data.Yscale_Movement/2))
         paint.drawRect(1, h1-6, records.MaxArrayDataLen-2, h2-h1+2)
 
 
@@ -342,20 +342,13 @@ def DrawGraph(self,  QtGui, ShowFiltered=False):
         #DRAW movement bars (yellow)
         paint.setPen(QtGui.QColor(data.MovementBarColor))
         peak=0
-    #    for p in range(GraphStart_index,  records.Index-data.Derivation,  Xscale):
         for p in range(0,  records.Index-data.Derivation,  Xscale):
             i=p-GraphStart_index
-    #        if(i>779*Xscale): break
-            #when Xscale is small, we have to merge several records into 1 pixel.
-            #Too not miss any movement, we use the biggest movement of the merged records:
             peak=0
             for j in range(0, Xscale):
-#                if(records.arrData[4][p+j]>peak): peak=records.arrData[4][p+j]
                 if(records.arrData[5][p+j]>peak): peak=records.arrData[5][p+j]
             x=i/Xscale
-    #        x=i/Xscale+1
-    #        paint.drawLine(x, data.Ysize-peak-1-15, x, data.Ysize-1-15)  #draw yellow movement bar
-            h=min(peak*data.Yscale/2,  data.Ysize-17) #cut off if higher than graph border
+            h=min(peak*data.Yscale_Movement/2,  data.Ysize-17) #cut off if higher than graph border
             paint.drawLine(x, data.Ysize-h-1-15, x, data.Ysize-1-15)  #draw yellow movement bar
 
 
@@ -376,7 +369,6 @@ def DrawGraph(self,  QtGui, ShowFiltered=False):
                 x=i/Xscale+1
                 y=data.Ysize-records.arrData[6][p+Xscale]-5
                 paint.drawLine(x, data.Ysize-16,       x, y)
-#                print p, records.arrData[0][p+Xscale], records.arrData[6][p+Xscale]
 
             #outline
             pen.setColor(QtGui.QColor(19, 54, 255))
@@ -388,8 +380,7 @@ def DrawGraph(self,  QtGui, ShowFiltered=False):
                 y0=data.Ysize-records.arrData[6][p]-5
                 y1=data.Ysize-records.arrData[6][p+Xscale]-5
                 paint.drawLine(x, y0,       x+1, y1)
-#                paint.drawLine(x, data.Ysize-records.arrData[6][p],       x+1, data.Ysize-records.arrData[6][p+Xscale])
-#                print records.arrData[6][p+Xscale], data.Ysize-records.arrData[6][p+Xscale]-5
+
 
 
 
@@ -470,20 +461,24 @@ def DrawGraph(self,  QtGui, ShowFiltered=False):
                 t=records.Trigger
             else:
                 t=data.Trigger
-#            offset=15 #visual correction to mach blue graph
-#            print t
-#            y=(data.Ysize-(t*data.Yscale/2))+offset
-#            print y
-#            y=(data.Ysize-(t/(61-data.FilterScale)))+offset
-            y=(data.Ysize-(t*data.FilterScale*3/40))+10
-
-#            print "--------------"
-#            print t,  t*data.FilterScale*3/40,  y
+            y=(data.Ysize-(t*data.Yscale_Sleep_Pattern*3/40))+10
             paint.setPen(QtGui.QColor(255,  255,  255, 200))
             paint.drawLine(1, y-17, data.GraphBitMapLen, y-17)  #Trigger line
+            if(y<18):
+                y=33
+                paint.drawLine(data.GraphBitMapLen-35, y-21,    data.GraphBitMapLen-35, y-30) #arrow
+                paint.drawLine(data.GraphBitMapLen-35, y-30,    data.GraphBitMapLen-32, y-27) #arrow
+                paint.drawLine(data.GraphBitMapLen-35, y-30,    data.GraphBitMapLen-38, y-27) #arrow
+            elif(y<33):
+                y=y+17
             paint.drawText(data.GraphBitMapLen-31, y-19, str(t)) #Trigger level
 
 
+        #show parameters
+        paint.setFont(QtGui.QFont('Decorative', 8))
+        paint.setPen(QtGui.QColor("gray"))
+        paint.drawText(data.GraphBitMapLen-70, data.Ysize+12, str(data.Yscale_Movement)+", "+str(data.Yscale_Sleep_Pattern)+", "+str(data.Yoffset_Sleep_Pattern)) #settings (for debbigging)
+
 
 
         #Draw border around graph
@@ -745,4 +740,4 @@ def PrintRecordData(ShowArray=True):
         for i in range(0, records.Index): #print data of  records
             print records.arrData[0][i],  records.arrData[1][i],  records.arrData[2][i],  records.arrData[3][i],  records.arrData[4][i],  records.arrData[5][i],  records.arrData[6][i]
 
-    print "##########################################################"
+    print "##########################################################"
\ No newline at end of file
