@@ -1387,12 +1387,28 @@ class frmConfigWindow(QMainWindow):
         self.ui = Ui_ConfigWindow()
         self.ui.setupUi(self)
         self.ui.lblIcon.setPixmap(QtGui.QPixmap(data.app_path+"img/"+"SleepAnalyser.png"))
+        self.ui.imgYscale_Movement.setPixmap(QtGui.QPixmap(data.app_path+"img/"+"Yscale_Movement.png"))
+        self.ui.imgYscale_Sleep_Pattern.setPixmap(QtGui.QPixmap(data.app_path+"img/"+"Yscale_Sleep_Pattern.png"))
+        self.ui.imgYoffset_Sleep_Pattern.setPixmap(QtGui.QPixmap(data.app_path+"img/"+"Yoffset_Sleep_Pattern.png"))
+        self.ui.imgDelayStart.setPixmap(QtGui.QPixmap(data.app_path+"img/"+"DelayStart.png"))
+
+        self.ui.bYscale_Movement_Reset.setIcon(QIcon(data.app_path+"img/"+"edit-undo.png"))
+        self.ui.bYscale_Sleep_Pattern_Reset.setIcon(QIcon(data.app_path+"img/"+"edit-undo.png"))
+        self.ui.bYoffset_Sleep_Pattern_Reset.setIcon(QIcon(data.app_path+"img/"+"edit-undo.png"))
+        self.ui.bDelayStart_Reset.setIcon(QIcon(data.app_path+"img/"+"edit-undo.png"))
 
         QtCore.QObject.connect(self.ui.bEditUserName, QtCore.SIGNAL("clicked()"), self.EditUserName)
         QtCore.QObject.connect(self.ui.SlrDelayStart,SIGNAL("valueChanged(int)"),self.DelaySliderMoved)
         QtCore.QObject.connect(self.ui.SlrYscale_Movement,SIGNAL("valueChanged(int)"),self.YscaleSliderMoved_Movement)
-        QtCore.QObject.connect(self.ui.SlrYscale_Sleep,SIGNAL("valueChanged(int)"),self.YscaleSliderMoved_Sleep)
-        QtCore.QObject.connect(self.ui.SlrYoffset_Sleep,SIGNAL("valueChanged(int)"),self.YoffsetSliderMoved_Sleep)
+        QtCore.QObject.connect(self.ui.SlrYscale_Sleep_Pattern,SIGNAL("valueChanged(int)"),self.YscaleSliderMoved_Sleep_Pattern)
+        QtCore.QObject.connect(self.ui.SlrYoffset_Sleep_Pattern,SIGNAL("valueChanged(int)"),self.YoffsetSliderMoved_Sleep_Pattern)
+        QtCore.QObject.connect(self.ui.bYscale_Movement_Reset, QtCore.SIGNAL("clicked()"), self.Yscale_Movement_Reset)
+        QtCore.QObject.connect(self.ui.bYscale_Sleep_Pattern_Reset, QtCore.SIGNAL("clicked()"), self.Yscale_Sleep_Pattern_Reset)
+        QtCore.QObject.connect(self.ui.bYoffset_Sleep_Pattern_Reset, QtCore.SIGNAL("clicked()"), self.Yoffset_Sleep_Pattern_Reset)
+        QtCore.QObject.connect(self.ui.bDelayStart_Reset, QtCore.SIGNAL("clicked()"), self.DelayStart_Reset)
+
+
+
 
 
         QtCore.QObject.connect(self.ui.bOK, QtCore.SIGNAL("clicked()"), self.OK)
@@ -1409,11 +1425,12 @@ class frmConfigWindow(QMainWindow):
         self.ui.tabWidget.setTabText(self.ui.tabWidget.indexOf(self.ui.tab_General), _("General"))
         self.ui.lblDelayStart.setText(_("Start delay:"))
         self.ui.lblYscale_Movement.setText(_("Y scaling movement (yellow):"))
-        self.ui.lblYscale_Sleep.setText(_("Y scaling sleep graph (blue):"))
-        self.ui.lblYoffset_Sleep.setText(_("Y offset sleep graph (blue):"))
-        self.ui.tabWidget.setTabText(self.ui.tabWidget.indexOf(self.ui.tab_Advanced), _("Advanced"))
-        self.ui.lblMore.setText(_("More settings can be changed at your own risk in the file\n~/.SleepAnalyer/SleepAnalyser.conf."))
-        self.ui.tabWidget.setTabText(self.ui.tabWidget.indexOf(self.ui.tab_More), _("More"))
+        self.ui.lblYscale_Sleep_Pattern.setText(_("Y scaling sleep graph (blue):"))
+        self.ui.lblYoffset_Sleep_Pattern.setText(_("Y offset sleep graph (blue):"))
+        self.ui.tabWidget.setTabText(self.ui.tabWidget.indexOf(self.ui.tab_Advanced_1), _("Advanced"+" 1"))
+        self.ui.tabWidget.setTabText(self.ui.tabWidget.indexOf(self.ui.tab_Advanced_2), _("Advanced"+" 2"))
+#        self.ui.lblMore.setText(_("More settings can be changed at your own risk in the file\n~/.SleepAnalyer/SleepAnalyser.conf."))
+#        self.ui.tabWidget.setTabText(self.ui.tabWidget.indexOf(self.ui.tab_More), _("More"))
         self.ui.bOK.setText(_("OK"))
 
         self.ui.tabWidget.setCurrentIndex(0)  #change to first page
@@ -1433,14 +1450,14 @@ class frmConfigWindow(QMainWindow):
         self.ui.lblDelayStart.setText(_("Start delay:")+" "+str(data.DelayStartTime)+" seconds")
         self.ui.SlrDelayStart.setValue(int(data.DelayStartTime))
 
-        self.ui.lblYscale_Movement.setText(_("Y scaling movement (yellow):")+" "+str(data.Yscale))
-        self.ui.SlrYscale_Movement.setValue(int(data.Yscale))
+        self.ui.lblYscale_Movement.setText(_("Y scaling movement (yellow):")+" "+str(data.Yscale_Movement))
+        self.ui.SlrYscale_Movement.setValue(int(data.Yscale_Movement))
 
-        self.ui.lblYscale_Sleep.setText(_("Y scaling sleep graph (blue):")+" "+str(data.FilterScale))
-        self.ui.SlrYscale_Sleep.setValue(int(data.FilterScale))
+        self.ui.lblYscale_Sleep_Pattern.setText(_("Y scaling sleep graph (blue):")+" "+str(data.Yscale_Sleep_Pattern))
+        self.ui.SlrYscale_Sleep_Pattern.setValue(int(data.Yscale_Sleep_Pattern))
 
-        self.ui.lblYoffset_Sleep.setText(_("Y offset sleep graph (blue):")+" "+str(data.Sleep_Pattern_Yoffset))
-        self.ui.SlrYoffset_Sleep.setValue(int(data.Sleep_Pattern_Yoffset))
+        self.ui.lblYoffset_Sleep_Pattern.setText(_("Y offset sleep graph (blue):")+" "+str(data.Yoffset_Sleep_Pattern))
+        self.ui.SlrYoffset_Sleep_Pattern.setValue(int(data.Yoffset_Sleep_Pattern))
 
 
 
@@ -1492,9 +1509,9 @@ class frmConfigWindow(QMainWindow):
 
         config.set('main', 'user', str(data.user.encode( "utf-8" )))
         config.set('main', 'DelayStartTime', str(data.DelayStartTime))
-        config.set('main', 'Yscale', str(data.Yscale))
-        config.set('main', 'FilterScale', str(data.FilterScale))
-        config.set('main', 'Sleep_Pattern_Yoffset', str(data.Sleep_Pattern_Yoffset))
+        config.set('main', 'Yscale', str(data.Yscale_Movement))
+        config.set('main', 'Yscale_Sleep_Pattern', str(data.Yscale_Sleep_Pattern))
+        config.set('main', 'Yoffset_Sleep_Pattern', str(data.Yoffset_Sleep_Pattern))
 
 
 
@@ -1520,26 +1537,57 @@ class frmConfigWindow(QMainWindow):
     ###########################################################################
     def YscaleSliderMoved_Movement(self): ##(Class ConfigWindow)
         x=self.ui.SlrYscale_Movement.value()
-        data.Yscale=int(x)
-        self.ui.lblYscale_Movement.setText(_("Y scaling movement (yellow):")+" "+str(data.Yscale))
+        data.Yscale_Movement=int(x)
+        self.ui.lblYscale_Movement.setText(_("Y scaling movement (yellow):")+" "+str(data.Yscale_Movement))
 
 
     ###########################################################################
     ##
     ###########################################################################
-    def YscaleSliderMoved_Sleep(self): ##(Class ConfigWindow)
-        x=self.ui.SlrYscale_Sleep.value()
-        data.FilterScale=int(x)
-        self.ui.lblYscale_Sleep.setText(_("Y scaling sleep graph (blue):")+" "+str(data.FilterScale))
+    def YscaleSliderMoved_Sleep_Pattern(self): ##(Class ConfigWindow)
+        x=self.ui.SlrYscale_Sleep_Pattern.value()
+        data.Yscale_Sleep_Pattern=int(x)
+        self.ui.lblYscale_Sleep_Pattern.setText(_("Y scaling sleep graph (blue):")+" "+str(data.Yscale_Sleep_Pattern))
 
 
     ###########################################################################
     ##
     ###########################################################################
-    def YoffsetSliderMoved_Sleep(self): ##(Class ConfigWindow)
-        x=self.ui.SlrYoffset_Sleep.value()
-        data.Sleep_Pattern_Yoffset=int(x)
-        self.ui.lblYoffset_Sleep.setText(_("Y offset sleep graph (blue):")+" "+str(data.Sleep_Pattern_Yoffset))
+    def YoffsetSliderMoved_Sleep_Pattern(self): ##(Class ConfigWindow)
+        x=self.ui.SlrYoffset_Sleep_Pattern.value()
+        data.Yoffset_Sleep_Pattern=int(x)
+        self.ui.lblYoffset_Sleep_Pattern.setText(_("Y offset sleep graph (blue):")+" "+str(data.Yoffset_Sleep_Pattern))
+
+
+
+    ###########################################################################
+    ##
+    ###########################################################################
+    def Yscale_Movement_Reset(self): ##(Class ConfigWindow)
+        self.ui.SlrYscale_Movement.setValue(int(data.Yscale_Movement_default))
+        self.YscaleSliderMoved_Movement()
+
+    ###########################################################################
+    ##
+    ###########################################################################
+    def Yscale_Sleep_Pattern_Reset(self): ##(Class ConfigWindow)
+        self.ui.SlrYscale_Sleep_Pattern.setValue(int(data.Yscale_Sleep_Pattern_default))
+        self.YscaleSliderMoved_Sleep_Pattern()
+
+    ###########################################################################
+    ##
+    ###########################################################################
+    def Yoffset_Sleep_Pattern_Reset(self): ##(Class ConfigWindow)
+        self.ui.SlrYoffset_Sleep_Pattern.setValue(int(data.Yoffset_Sleep_Pattern_default))
+        self.YoffsetSliderMoved_Sleep_Pattern()
+
+    ###########################################################################
+    ##
+    ###########################################################################
+    def DelayStart_Reset(self): ##(Class ConfigWindow)
+        self.ui.SlrDelayStart.setValue(int(data.DelayStartTime_default))
+        self.DelaySliderMoved()
+
 
 
 
